@@ -235,88 +235,6 @@ Rcpp::List method_eigenmaps(arma::mat& W){
 // 5. sammon : sammon mapping updates
 // X     : (p-by-n) for armadillo convenience
 // Yinit : (n-by-d)
-// [[Rcpp::export]]
-arma::mat method_sammon(arma::mat& X, arma::mat& Yinit){
-  // 5-1. basic settings
-  const int n = Yinit.n_rows;
-  const int d = Yinit.n_cols;
-
-  // 5-2. iteration prep
-  mat Yold = Yinit;
-  mat Ynew(n,d);
-
-  const int maxiter = 1000;
-  const double thrstop = 1e-10;
-  double incnorm;
-
-  // 5-3. common values from original matrix X
-  mat DPJX(n,n);
-  double c = 0;
-  for (int i=0;i<n;i++){
-    for (int j=i;j<n;j++){
-      if (i!=j){
-        double DPJXstar = norm(X.col(i)-X.col(j),2);
-        DPJX(i,j) = DPJXstar;
-        DPJX(j,i) = DPJXstar;
-        c += DPJXstar;
-      }
-    }
-  }
-
-  // 5-4. main iteration
-  mat DPJY(n,n);
-  for (int m=0;m<maxiter;m++){
-   //  5-4-1. define & compute new DPJ for current iterate
-    DPJY.zeros();
-    for (int i=0;i<n;i++){
-      for (int j=i;j<n;j++){
-        if (i!=j){
-          double DPJcurrent = norm(Yold.row(i)-Yold.row(j));
-          DPJY(i,j) = DPJcurrent;
-          DPJY(j,i) = DPJcurrent;
-        }
-      }
-    }
-    //  5-4-2. update with for Ynew
-    for (int p=0;p<n;p++){
-      for (int q=0;q<d;q++){
-        double der1 = 0;
-        double der2 = 0;
-
-        for (int j=0;j<n;j++){
-          if (p!=j){
-            double dpjstar = DPJX(p,j);
-            double dpj     = DPJY(p,j);
-            der1 += ((dpjstar-dpj)/(dpjstar*dpj))*(Yold(p,q)-Yold(j,q));
-            der2 += (dpjstar-dpj)-(pow((Yold(p,q)-Yold(j,q)),2)/dpj)*(1+((dpjstar-dpj)/dpj));
-          }
-        }
-
-        der1 *= (-2/c);
-        der2 *= (-2/c);
-        if (der2 < 0){
-          der2 *= -1;
-        }
-
-        Ynew(p,q) = Yold(p,q) - 0.3*(der1/der2);
-      }
-    }
-
-    //  5-4-3. Break with incremental norm condition
-    incnorm = norm(Yold-Ynew);
-    if (incnorm < thrstop){
-      Yold = Ynew;
-      break;
-    }
-
-    //  5-4-4. update
-    Yold = Ynew;
-  }
-
-  // 5-5. return output
-  return(Yold);
-}
-
 
 
 // 6. lleW : compute weight matrix W
